@@ -2,7 +2,7 @@ package Pandoc::Walker;
 use strict;
 use warnings;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Scalar::Util qw(reftype blessed);
 use parent 'Exporter';
@@ -15,13 +15,13 @@ sub transform {
     my $reftype = reftype($ast) || ''; 
 
     if ($reftype eq 'ARRAY') {
-        my $i = 0;
-        foreach my $item (@$ast) {
+        for (my $i=0; $i<@$ast; ) {
+            my $item = $ast->[$i];
             if ((reftype $item || '') eq 'HASH' and $item->{t}) {
                 my $res = $action->($item, @_);
                 # replace current item with result element(s)
                 if (defined $res) {
-                    my @elements = map { transform($_, $action, @_) } 
+                    my @elements = #map { transform($_, $action, @_) } 
                         (reftype $res || '') eq 'ARRAY' ? @$res : $res;
                     splice @$ast, $i, 1, @elements;
                     $i += scalar @elements;
@@ -70,9 +70,9 @@ Pandoc::Walker - utility functions to traverse Pandoc documents
 =head1 SYNOPSIS
 
     use Pandoc::Walker;
-    use JSON;
+    use Pandoc::Elements qw(pandoc_json);
 
-    my $ast = decode_json(<>);
+    my $ast = pandoc_json(<>);
 
     # extract all links
     my $links = query $ast, sub {
